Installation
============

BlazeFL is available on PyPI and can be installed using your preferred package manager.

For example:

.. code-block:: bash

   uv add blazefl
   # or
   poetry add blazefl
   # or
   pip install blazefl
